@@ -20,6 +20,8 @@
 #include "Python.h"
 #include "_libdna.h"
 
+#include "bitpack.h"
+
 PyDoc_STRVAR(module_doc,
 	     "C-level utilities to work with DNA, in particular if considering"
 	     "bit-packing.");
@@ -98,14 +100,15 @@ static inline Py_ssize_t nbytes_for_bit2(Py_ssize_t n) {
 static inline void bytes_to_bit2(const char *read, const Py_ssize_t n, 
 				 char *bit2_ptr, const Py_ssize_t bit2_n)
 {
-  Py_ssize_t i, bit2_i;
+  Py_ssize_t bytes_i, bit2_i;
   unsigned char cur_byte;
 
   bit2_i = 0;
+  /* position within a byte when bit2packing */
   unsigned int bitpos = 6;
 
   bit2_ptr[bit2_i] = 0;
-  for (i=0; i < n; i++)
+  for (bytes_i=0; bytes_i < n; bytes_i++)
     {
 
       if (bitpos == -2) {
@@ -113,11 +116,12 @@ static inline void bytes_to_bit2(const char *read, const Py_ssize_t n,
 	bit2_i++;
 	bit2_ptr[bit2_i] = 0;
 	if (bit2_i >= bit2_n) {
-	  printf("Out of range (unpacked #%zd, packed #%zd >= #%zd).\n", i, bit2_i, bit2_n);
+	  printf("Out of range (unpacked #%zd, packed #%zd >= #%zd).\n",
+		 bytes_i, bit2_i, bit2_n);
 	}
       }
 
-      cur_byte = _ASCII_TO_BIT2[(unsigned char)read[i]];
+      cur_byte = _ASCII_TO_BIT2[(unsigned char)read[bytes_i]];
       bit2_ptr[bit2_i] |= (cur_byte << (bitpos));
 
       bitpos -= 2;
@@ -386,7 +390,7 @@ static inline void packeddna_fromslice(const Py_ssize_t ilow,
 
 
 PyDoc_STRVAR(slicebit2_frombit2bytes_doc,
-"Takes a bytes object with 2-bit packed DNA values, a slice with coordinates on the unpacked sequence, and returns a 2-bit packed slice. As with other Python slices the last element is not included.");
+"slice_frombit2bytes(bit2packed, start, stop)\nTakes a bytes object with 2-bit packed DNA values, a slice with coordinates on the unpacked sequence, and returns a 2-bit packed slice. As with other Python slices the last element is not included.");
 static PyObject* slicebit2_frombit2bytes(PyObject *self, PyObject *args)
 {
 
@@ -597,7 +601,7 @@ static PyObject* slice_frombit2bytearray(PyObject *self, PyObject *args)
 
 
 
-static PyMethodDef libxsq_methods[] = {
+static PyMethodDef libdna_methods[] = {
   {"bit2_frombytes", (PyCFunction)bit2_frombytes,  METH_O,
    bit2_frombytes_doc},
   {"bit2_frombytearray", (PyCFunction)bit2_frombytearray,  METH_O,
@@ -638,7 +642,7 @@ static struct PyModuleDef libdnamodule = {
    "_libdna",           /* name of module */
    module_doc,               /* module documentation, may be NULL */
    -1,                     /* size of per-interpreter state */
-   libxsq_methods       /* method table */
+   libdna_methods       /* method table */
  };
 #endif
 
@@ -663,7 +667,7 @@ PyInit__libdna(void)
   //PyObject *c_api_object;
 
 #if (PY_VERSION_HEX < 0x03010000)
-  m = Py_InitModule3("_libdna", libxsq_methods, module_doc);
+  m = Py_InitModule3("_libdna", libdna_methods, module_doc);
 #else
   m = PyModule_Create(&libdnamodule);
 #endif
