@@ -24,15 +24,15 @@ class LibxsqTestCase(unittest.TestCase):
                     c = str(c)
                 else:
                     c = bytes(str(c), 'ASCII')[0]
-            self.assertEquals(c, col[i]);
+            self.assertEqual(c, col[i]);
         for i, x in enumerate(bt):
             # Python 3
             if sys.version_info[0] < 3:
                 q = ord(x) >> 2
-                self.assertEquals(q, ord(qual[i]));
+                self.assertEqual(q, ord(qual[i]));
             else:
                 q = x >> 2
-                self.assertEquals(q, qual[i]);
+                self.assertEqual(q, qual[i]);
 
     def test_colourqual_frombytearray(self):
         self.assertRaises(TypeError, _libxsq.colourqual_frombytearray, 10)
@@ -58,15 +58,15 @@ class LibxsqTestCase(unittest.TestCase):
                 c = b'N'
             else:
                 c = b'ACGT'[c]
-            self.assertEquals(c, base[i]);
+            self.assertEqual(c, base[i]);
         for i, x in enumerate(bt):
             # Python 3
             if sys.version_info[0] < 3:
                 q = ord(x) >> 2
-                self.assertEquals(q, ord(qual[i]));
+                self.assertEqual(q, ord(qual[i]));
             else:
                 q = x >> 2
-                self.assertEquals(q, qual[i]);
+                self.assertEqual(q, qual[i]);
 
 
 def suite():
