@@ -7,9 +7,13 @@ from ngs_plumbing.fastq import write_fastq
 from ngs_plumbing.fastq import read_fastq
 from ngs_plumbing.fasta import write_fasta, write_qual
 
-
-_DENCODE = string.maketrans('0123.', 'ATGCN')
-_DDECODE = string.maketrans('ATGCNatgcn', '0123.0123.')
+# compatibility with Python2
+if sys.version_info[0] < 3:
+    _DENCODE = string.maketrans('0123.', 'ATGCN')
+    _DDECODE = string.maketrans('ATGCNatgcn', '0123.0123.')
+else:
+    _DENCODE = str.maketrans('0123.', 'ATGCN')
+    _DDECODE = str.maketrans('ATGCNatgcn', '0123.0123.')
 
 
 def dencode_seq(seq):
