@@ -47,26 +47,37 @@ from ngs_plumbing._libdna import slice_frombit2bytes
 from ngs_plumbing._libdna import bit2_frombytes, bit2_frombytearray, bit2_frombuffer
 from ngs_plumbing._libdna import bit2reverse_frombit2bytes, bit2complement_frombit2bytes, bit2reversecomplement_frombit2bytes
 from ngs_plumbing.ngsp_string import sequentialfragments, sequentialfragments_iter, randomstring
+
+# Compatibility with Python 3
+import sys
+if sys.version_info[0] > 2:
+    xrange = range
+
 # A: 0b00
 # C: 0b01
 # G: 0b10
 # T: 0b11
-_alphabet = bytes('ACGT')
+_alphabet = b'ACGT'
 _bit2_to_dna = _alphabet
 # arbitrary: put an A when out of the alphabet
 # error checking is assumed to take place upstream
-_dna_to_bit2 = array('i', (0b00 for x in xrange(255)))
+_dna_to_bit2 = array('i', (0b00 for x in range(255)))
+
 for val, b in enumerate(_bit2_to_dna):
-    i = ord(b)
-    _dna_to_bit2[i] = val
-del(b, val, i)
+    if sys.version_info[0] < 3:
+        i = ord(b)
+        _dna_to_bit2[i] = val
+    else:
+        _dna_to_bit2[b] = val
+del(b, val)
+
 
 # also store pairs (masking + lookups to be done divided by 2)
 _bit2_to_dna2 = tuple(l1+l2 for i2,l2 in enumerate(_alphabet) \
                           for i1,l1 in enumerate(_alphabet))
 
 
-_alphabet_n = bytes('ATGCN')
+_alphabet_n = b'ATGCN'
 _alphabet_to_bits = {b'A': (0b000, ),
                      b'T': (0b001, ),
                      b'G': (0b110, ),
@@ -75,17 +86,20 @@ _alphabet_to_bits = {b'A': (0b000, ),
 
 # setup byte<->integer mappings
 _bit3_to_dna = list(b'N' * 8)
-for k,v in _alphabet_to_bits.iteritems():
+for k,v in _alphabet_to_bits.items():
     for i in v:
         _bit3_to_dna[i] = k
-_bit3_to_dna = bytes(''.join(_bit3_to_dna))
+_bit3_to_dna = b''.join(_bit3_to_dna)
 del(k, v, i)
 
-_dna_to_bit3 = array('i', (_alphabet_to_bits[b'N'][0] for x in xrange(255)))
+_dna_to_bit3 = array('i', (_alphabet_to_bits[b'N'][0] for x in range(255)))
 for val, b in enumerate(_bit3_to_dna):
-    i = ord(b)
-    _dna_to_bit3[i] = val
-del(b, val, i)
+    if sys.version_info[0] < 3:
+        i = ord(b)
+        _dna_to_bit3[i] = val
+    else:
+        _dna_to_bit3[b] = val
+del(b, val)
 # ---
 
 def randomgenome(size):
