@@ -35,7 +35,7 @@ except ImportError:
 from ngs_plumbing import _libxsq_test
 from ngs_plumbing import _libdna_test
 from ngs_plumbing import _libdnaqual_test
-
+from ngs_plumbing import sampling_test
 
 def suite():
     suite_string = string_test.suite()
@@ -51,6 +51,7 @@ def suite():
     suite_libxsq = _libxsq_test.suite()
     suite_libdna = _libdna_test.suite()
     suite_libdnaqual = _libdnaqual_test.suite()
+    suite_sampling = sampling_test.suite()
 
     l = [suite_string,
          suite_dna,
@@ -62,7 +63,8 @@ def suite():
          suite_libxsq,
          suite_libdna,
          suite_libdnaqual,
-         suite_parsing]
+         suite_parsing,
+         suite_sampling]
     if has_xsq:
         l.append(suite_xsq)
     alltests = unittest.TestSuite(l)
