@@ -29,8 +29,8 @@ bitwise_and = numpy.bitwise_and
 from ngs_plumbing.dnaqual import DnaQual
 from ngs_plumbing._libxsq import colourqual_frombuffer, basequal_frombuffer, bytearray_phredtoascii, bytearray_addint
 
-if sys.version_info[0] > 2:
-    xrange = range
+if sys.version_info[0] < 3:
+    range = xrange
 
 ColourQual = namedtuple('ColourQual', 'colour qual')
 
@@ -51,6 +51,8 @@ FRAGMENT_START = {'F3': 'T',
 _pack_installdir = os.path.abspath(os.path.dirname(__file__))
 testdata_dir = os.path.join(_pack_installdir, 'data')
 
+inc = int(1)
+
 def list_xsq(path):
     """ list XSQ (.xsq) files in a given directory """
     for path,dirs,files in os.walk(path):
@@ -60,6 +62,9 @@ def list_xsq(path):
                        
 class FragmentError(KeyError):
     pass
+class DataError(KeyError):
+    pass
+
 class InvalidXSQError(ValueError):
     pass
 
@@ -208,7 +213,12 @@ def _read_values(group, fragment, what):
 def tile_valuearray(tile, fragment, what):
     """ Get the array of values for a tile. """
     if fragment not in tile:
-        raise FragmentError('No such fragment "%s"' %fragment)
+        raise FragmentError('No such fragment "%s", only '
+                            '(%s)' % (fragment, ','.join(tile.keys())))
+    elif what not in tile[fragment]:
+        raise DataError('No such data "%s", only '
+                        '(%s)' % (what, ', '.join(tile[fragment].keys())))
+
     ds = tile[fragment][what].value
     a = numpy.empty(shape = ds.shape, dtype = ds.dtype)
         #FIXME: force copy into memory, presumably. Is this is always wise, or even true ?
@@ -257,7 +267,7 @@ def iter_fastq_reads(group, fragment, numbase):
     - numbase: number of bases (read length)
     """
     for tile_n, a in iter_valuearrays(group, fragment, what='BaseCallQV'):
-        for row_i in xrange(a.shape[0]): 
+        for row_i in range(a.shape[0]): 
             dna, qual = basequal_frombuffer(a[row_i])
             qual = bytearray_phredtoascii(qual)
             yield DnaQual(dna, qual)
@@ -273,7 +283,7 @@ def iter_csfasta_reads(group, fragment, numbase):
     - numbase: number of bases (read length)
     """
     for tile_n, a in iter_valuearrays(group, fragment, what='ColorCallQV'):
-        for row_i in xrange(a.shape[0]):
+        for row_i in range(a.shape[0]):
             colour, qual = colourqual_frombuffer(a[row_i])
             yield ColourQual(colour, qual)
 
@@ -402,17 +412,57 @@ def _progress_bar_iter(iterator, size = 20, out = sys.stdout, suffix = ''):
                 out.flush()
         yield i
 
+def _xsqvalues_to_fastq(xsqvalues, xyloc,
+                        buf, seq_id, prefix, n_count, n_perfect):
+    if sys.version_info[0] > 2:
+        for row_i in range(xsqvalues.shape[0]):
+                dna, qual = basequal_frombuffer(xsqvalues[row_i])
+                qual = bytearray_phredtoascii(qual)
+                #yield DnaQual(dna, qual)
+
+                n_count_read = dna.count(b'N')
+                n_count += n_count_read
+                if n_count_read == 0:
+                    n_perfect += inc
+                x,y = xyloc[row_i]
+                buf.writelines((bytes(seq_id %(x,y), 'ASCII'), 
+                                b'\n', 
+                                dna, 
+                                b'\n+\n', 
+                                qual, b'\n'))
+    else:
+        for row_i in range(xsqvalues.shape[0]):
+                dna, qual = basequal_frombuffer(xsqvalues[row_i])
+                qual = bytearray_phredtoascii(qual)
+                #yield DnaQual(dna, qual)
+
+                n_count_read = dna.count(b'N')
+                n_count += n_count_read
+                if n_count_read == 0:
+                    n_perfect += inc
+                x,y = xyloc[row_i]
+                buf.writelines((seq_id %(x,y), '\n', dna, 
+                                '\n+\n', qual, '\n'))
+    return (n_count, n_perfect, len(dna))
+
 def make_fastq(lib, fragment, buf, f, flowcell, numbase = None, 
                progress_mark = 50000, out=sys.stdout):
     n_count = int(0)
     n_perfect = int(0)
     read_count = int(0)
-    inc = int(1)
 
-    for tile_i, (tile_n, a) in enumerate(iter_valuearrays(lib, fragment, what='BaseCallQV')):
+    if sys.version_info[0] == 2:
+        block = '\xe2\x96\x88'
+    else:
+        block = u"\u2588"
+
+    it = enumerate(iter_valuearrays(lib, fragment, 
+                                    what='BaseCallQV'))
+    for tile_i, (tile_n, a) in it:
         if numbase is None:
             numbase = a.shape[1]
 
+        prefix = FRAGMENT_START[fragment]
         seq_id = seqid_template(f, flowcell, tile_n)
         xyloc = lib[tile_n]['Fragments'][u'yxLocation'][:]
 
@@ -423,18 +473,10 @@ def make_fastq(lib, fragment, buf, f, flowcell, numbase = None,
                                       ' ' * (20 - ms), tile_i+1))
         out.flush()
 
-        for row_i in xrange(a.shape[0]):
-            dna, qual = basequal_frombuffer(a[row_i])
-            qual = bytearray_phredtoascii(qual)
-            #yield DnaQual(dna, qual)
-
-            n_count_read = dna.count(b'N')
-            n_count += n_count_read
-            if n_count_read == 0:
-                n_perfect += inc
-            dna_b = bytes(dna, 'ASCII')
-            x,y = xyloc[row_i]
-            buf.writelines((seq_id %(x,y), '\n', dna_b, '\n+\n', qual, '\n'))
+        n_count, n_perfect, read_length = _xsqvalues_to_fastq(a, xyloc,
+                                                              buf, seq_id, 
+                                                              prefix, 
+                                                              n_count, n_perfect)
 
         #numbase = None
 
@@ -443,7 +485,7 @@ def make_fastq(lib, fragment, buf, f, flowcell, numbase = None,
     out.write("%i reads. ((%.3fGb, %.3f%% perfect , %.5f%% Ns)\n" %(read_count, 
                                                                     read_count*numbase / 1E9,
                                                                     100.0*n_perfect/read_count,  
-                                                                    n_count * 100.0 / (read_count * len(dna))))
+                                                                    n_count * 100.0 / (read_count * read_length)))
     out.flush()
 
 
@@ -454,7 +496,7 @@ def _xsqvalues_to_csfasta(xsqvalues, xyloc, buf_cs, buf_qual, seq_id, prefix):
         return
     bases_i = range(xsqvalues.shape[1]-1)
     if sys.version_info[0] > 2:
-        for row_i in xrange(xsqvalues.shape[0]): 
+        for row_i in range(xsqvalues.shape[0]): 
             seq, qual = colourqual_frombuffer(xsqvalues[row_i])
             x,y = xyloc[row_i]
             this_seq_id = seq_id % (x,y)
@@ -465,7 +507,7 @@ def _xsqvalues_to_csfasta(xsqvalues, xyloc, buf_cs, buf_qual, seq_id, prefix):
                 buf_qual.write('%i ' % qual[q_i])
             buf_qual.writelines((str(qual[len(bases_i)]), '\n'))
     else:
-        for row_i in xrange(xsqvalues.shape[0]): 
+        for row_i in range(xsqvalues.shape[0]): 
             seq, qual = colourqual_frombuffer(xsqvalues[row_i])
             x,y = xyloc[row_i]
             this_seq_id = seq_id % (x,y)
@@ -480,7 +522,6 @@ def _xsqvalues_to_csfasta(xsqvalues, xyloc, buf_cs, buf_qual, seq_id, prefix):
 def make_csfasta(lib, fragment, buf_cs, buf_qual, f, flowcell, 
                  numbase = None, progress_mark = 50000, out=sys.stdout):
     read_count = int(0)
-    inc = int(1)
     if sys.version_info[0] == 2:
         block = '\xe2\x96\x88'
     else:
@@ -509,7 +550,7 @@ def make_csfasta(lib, fragment, buf_cs, buf_qual, f, flowcell,
 
 def _xsqvalues_to_csfastq(xsqvalues, xyloc, buf, seq_id, prefix):
     if sys.version_info[0] > 2:
-        for row_i in xrange(xsqvalues.shape[0]):
+        for row_i in range(xsqvalues.shape[0]):
             seq, qual = colourqual_frombuffer(xsqvalues[row_i])
             seq = bytearray_addint(seq, 48)
             qual = bytearray_phredtoascii(qual)
@@ -518,7 +559,7 @@ def _xsqvalues_to_csfastq(xsqvalues, xyloc, buf, seq_id, prefix):
                             '\n+\n', qual.decode('ASCII'), '\n'))
     else:
         seq_id = seq_id.encode('ASCII')
-        for row_i in xrange(xsqvalues.shape[0]):
+        for row_i in range(xsqvalues.shape[0]):
             seq, qual = colourqual_frombuffer(xsqvalues[row_i])
             seq = bytearray_addint(seq, 48)
             qual = bytearray_phredtoascii(qual)
@@ -529,7 +570,6 @@ def _xsqvalues_to_csfastq(xsqvalues, xyloc, buf, seq_id, prefix):
 def make_csfastq(lib, fragment, buf, f, flowcell, 
                  numbase = None, progress_mark = 50000, out=sys.stdout):
     read_count = int(0)
-    inc = int(1)
     if sys.version_info[0] == 2:
         block = '\xe2\x96\x88'
     else:
@@ -658,13 +698,12 @@ def fastqual(xsqlib, fragment, what, sample = 0.05):
     nfragments = xsqlib.readcount()
     nsample = int(sample * nfragments)
     reads_idx = [None, ] * nsample
-    for i in xrange(nsample):
+    for i in range(nsample):
         reads_idx[i] = random.randint(0, nfragments-1)
     reads_idx.sort()
     #reads_idx.reverse()
 
     # fetch the reads
-    inc = int(1)
     #FIXME: read length hardcoded - fetch it from the XSQ
     readlength = 75
     maxval = 64
@@ -693,10 +732,10 @@ def fastqual(xsqlib, fragment, what, sample = 0.05):
 
 from ngs_plumbing import report
 import csv, json
-import jinja2
 
 def make_htmlreport(xsqfile, directory = '.', verbose = True,
                     sample_percent = 0.05, data_type = 'json'):
+    import jinja2
     assert(isinstance(xsqfile, XSQFile))
     assert(data_type in ('json', 'csv'))
     pl = jinja2.PackageLoader('ngs_plumbing', 
